import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import pystan
import seaborn as sb

xlfile = pd.ExcelFile('fructose.xlsx')
print(xlfile)
df = pd.read_excel(xlfile)
print(df)
col_names = df.keys()
print(col_names)
Xf = df['Temperature'].values
Yf = df['Sweetness'].values
Gf = np.ones(len(Xf))         #    ダミー変数 G=1
print('Xf =\n', Xf)
print('Yf =\n', Yf)
print('Gf =\n', Gf)

xlfile = pd.ExcelFile('glucose.xlsx')
print(xlfile)
df = pd.read_excel(xlfile)
print(df)
col_names = df.keys()
print(col_names)
Xg = df['Temperature'].values
Yg = df['Sweetness'].values
Gg = np.zeros(len(Xf))        #   ダミー変数 G = 0
print('Xg =\n', Xg)
print('Yg =\n', Yg)
print('Gg =\n', Gg)

X = np.concatenate((Xf,Xg))
Y = np.concatenate((Yf, Yg))
G = np.concatenate((Gf, Gg))
print('X =\n', X)
print('Y =\n', Y)
print('G =\n', G)

sm = pystan.StanModel(file = 'ModelDummy.stan')
print('Compilation ended.')

Z = X - np.mean(X)
Data = {'N':len(Y), 'Y':Y, 'X':Z, 'G':G}
fit = sm.sampling(data = Data, n_jobs = 1)
print(fit)

sgm_hat = np.median(fit['sgm'])
sb.kdeplot(fit['sgm'])
plt.title('Sigma: median = {0:.2}'.format(sgm_hat))
plt.savefig('FigSgm.png')
plt.show()

Y_hat = np.empty(len(Y))
a1_hat = np.median(fit['a1'])
a2_hat = np.median(fit['a2'])
b1_hat = np.median(fit['b1'])
b2_hat = np.median(fit['b2'])

sb.kdeplot(fit['a1'], label = 'a1')
sb.kdeplot(fit['a2'], label = 'a2')
plt.title('a1: median={0:.2f},   a2: median={1:.2f}'.format(
    a1_hat, a2_hat))
plt.legend()
plt.savefig('Figa1a2.png')
plt.show()

sb.kdeplot(fit['b1'], label = 'b1')
sb.kdeplot(fit['b2'], label = 'b2')
plt.title('b1: median={0:.4f},   b2: median={1:.4f}'.format(
    b1_hat, b2_hat))
plt.xticks(rotation = 45)
plt.legend()
plt.tight_layout()
plt.savefig('Figb1b2.png')
plt.show()

plt.plot(Z, Y, 'o')
print(np.min(Z), np.max(Z))
plt.plot([np.min(Z), np.max(Z)], [a1_hat + b1_hat*np.min(Z), a1_hat + b1_hat*np.max(Z)],
        label = 'glucose')
plt.plot([np.min(Z), np.max(Z)],
         [a1_hat + a2_hat + (b1_hat + b2_hat)*np.min(Z), a1_hat + a2_hat + (b1_hat + b2_hat)*np.max(Z)],
         label = 'fructose')
x_coord = np.arange(0, 61, 10)
z_coord = x_coord - np.mean(X)
plt.xticks(z_coord, x_coord)
plt.xlabel('$^{\circ}C$', fontsize = 14)
plt.ylabel('Sweetness')
plt.plot([0, 0], [np.min(Y), np.max(Y)], label = 'Mean of X = {0:.1f}'.format(np.mean(X)))
plt.legend()
plt.tight_layout()
plt.savefig('FigRegressDummy.png')
plt.show()

print('Mean of X = {0:.5f}'.format(np.mean(X)))

ck_b1 = [1 if v < 0 else 0 for v in fit['b1']]
print('Prop(b1 < 0) = {0:.5f}'.format(np.sum(ck_b1) / len(ck_b1)))


